--- ../nagios-cvs-org/xdata/xpddefault.c	2004-12-06 04:40:03.000000000 +0100
+++ xdata/xpddefault.c	2005-05-07 10:52:56.000000000 +0200
@@ -641,6 +641,7 @@ int xpddefault_preprocess_file_templates
 int xpddefault_update_service_performance_data_file(service *svc){
 	char raw_output[MAX_INPUT_BUFFER];
 	char processed_output[MAX_INPUT_BUFFER];
+	char temp_buffer[MAX_INPUT_BUFFER];
 	host *temp_host;
 	int result=OK;
 
@@ -673,9 +674,21 @@ int xpddefault_update_service_performanc
 #endif
 
 	/* write the processed output line containing performance data to the service perfdata file */
-	fputs(processed_output,xpddefault_service_perfdata_fp);
-	fputs("\n",xpddefault_service_perfdata_fp);
-	fflush(xpddefault_service_perfdata_fp);
+
+	/* Ignore the SIGPIPE signal that normally would terminate the program in case the pipe has lost its
+	   receiving process */
+	signal(SIGPIPE, SIG_IGN);
+
+	if (EOF==fputs(processed_output,xpddefault_service_perfdata_fp) ||
+	    EOF==fputs("\n",xpddefault_service_perfdata_fp) ||
+		EOF==fflush(xpddefault_service_perfdata_fp)){
+		snprintf(temp_buffer,sizeof(temp_buffer),"Warning: Error writing Service performance data to file");
+		temp_buffer[sizeof(temp_buffer)-1]='\x0';
+		write_to_logs_and_console(temp_buffer,NSLOG_RUNTIME_WARNING,TRUE);
+		}
+
+	/* reset the SIGPIPE signal again */
+	signal(SIGPIPE, SIG_DFL);
 
 	return result;
         }
@@ -685,6 +698,7 @@ int xpddefault_update_service_performanc
 int xpddefault_update_host_performance_data_file(host *hst){
 	char raw_output[MAX_INPUT_BUFFER];
 	char processed_output[MAX_INPUT_BUFFER];
+	char temp_buffer[MAX_INPUT_BUFFER];
 	int result=OK;
 
 	/* we don't have a host perfdata file */
@@ -712,9 +726,21 @@ int xpddefault_update_host_performance_d
 #endif
 
 	/* write the processed output line containing performance data to the host perfdata file */
-	fputs(processed_output,xpddefault_host_perfdata_fp);
-	fputs("\n",xpddefault_host_perfdata_fp);
-	fflush(xpddefault_host_perfdata_fp);
+
+	/* Ignore the SIGPIPE signal that normally would terminate the program in case the pipe has lost its
+	   receiving process */
+	signal(SIGPIPE, SIG_IGN);
+
+	if (EOF==fputs(processed_output,xpddefault_host_perfdata_fp)||
+		EOF==fputs("\n",xpddefault_host_perfdata_fp) ||
+		EOF==fflush(xpddefault_host_perfdata_fp)){
+		snprintf(temp_buffer,sizeof(temp_buffer),"Warning: Error writing Host performance data to file");
+		temp_buffer[sizeof(temp_buffer)-1]='\x0';
+		write_to_logs_and_console(temp_buffer,NSLOG_RUNTIME_WARNING,TRUE);
+		}
+
+	/* reset the SIGPIPE signal again */
+	signal(SIGPIPE, SIG_DFL);
 
 	return result;
         }
